triad.census returns the Davis and Leinhardt triad census of the elements of dat indicated by g.
triad.census(dat, g=NULL, mode = c("digraph", "graph"))dat to process. "digraph" implies a directed structure, whereas "graph" implies an undirected structure.triad.census is a front end for the triad.classify routine, performing the classification for all triads within the selected graphs. The results are placed in the order indicated by the column names; this is the same order as presented in the triad.classify documentation, to which the reader is referred for additional details.In the undirected case, the triad census reduces to four states (based on the number of edges in each triad. Where mode=="graph", this is returned instead.
Compare triad.census to dyad.census, the dyadic equivalent.
Wasserman, S., and Faust, K. (1994). ``Social Network Analysis: Methods and Applications.'' Cambridge: Cambridge University Press.
triad.classify, dyad.census, kcycle.census, kpath.census, gtrans #Generate a triad census of random data with varying densities
triad.census(rgraph(15,5,tprob=c(0.1,0.25,0.5,0.75,0.9)))
Run the code above in your browser using DataLab